@@ -28,6 +28,7 @@ from .literals import (
     LogTypeType,
     OptionStateType,
     OutboundCrossClusterSearchConnectionStatusCodeType,
+    OverallChangeStatusType,
     PackageStatusType,
     ReservedElasticsearchInstancePaymentOptionType,
     RollbackOnDisableType,
@@ -71,6 +72,9 @@ __all__ = (
     "AutoTuneTypeDef",
     "CancelElasticsearchServiceSoftwareUpdateRequestRequestTypeDef",
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
+    "ChangeProgressDetailsTypeDef",
+    "ChangeProgressStageTypeDef",
+    "ChangeProgressStatusDetailsTypeDef",
     "CognitoOptionsStatusTypeDef",
     "CognitoOptionsTypeDef",
     "ColdStorageOptionsTypeDef",
@@ -91,6 +95,8 @@ __all__ = (
     "DeletePackageResponseTypeDef",
     "DescribeDomainAutoTunesRequestRequestTypeDef",
     "DescribeDomainAutoTunesResponseTypeDef",
+    "DescribeDomainChangeProgressRequestRequestTypeDef",
+    "DescribeDomainChangeProgressResponseTypeDef",
     "DescribeElasticsearchDomainConfigRequestRequestTypeDef",
     "DescribeElasticsearchDomainConfigResponseTypeDef",
     "DescribeElasticsearchDomainRequestRequestTypeDef",
@@ -400,6 +406,40 @@ CancelElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
     },
 )
 
+ChangeProgressDetailsTypeDef = TypedDict(
+    "ChangeProgressDetailsTypeDef",
+    {
+        "ChangeId": str,
+        "Message": str,
+    },
+    total=False,
+)
+
+ChangeProgressStageTypeDef = TypedDict(
+    "ChangeProgressStageTypeDef",
+    {
+        "Name": str,
+        "Status": str,
+        "Description": str,
+        "LastUpdated": datetime,
+    },
+    total=False,
+)
+
+ChangeProgressStatusDetailsTypeDef = TypedDict(
+    "ChangeProgressStatusDetailsTypeDef",
+    {
+        "ChangeId": str,
+        "StartTime": datetime,
+        "Status": OverallChangeStatusType,
+        "PendingProperties": List[str],
+        "CompletedProperties": List[str],
+        "TotalNumberOfStages": int,
+        "ChangeProgressStages": List["ChangeProgressStageTypeDef"],
+    },
+    total=False,
+)
+
 CognitoOptionsStatusTypeDef = TypedDict(
     "CognitoOptionsStatusTypeDef",
     {
@@ -623,6 +663,36 @@ DescribeDomainAutoTunesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeDomainChangeProgressRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeDomainChangeProgressRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalDescribeDomainChangeProgressRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeDomainChangeProgressRequestRequestTypeDef",
+    {
+        "ChangeId": str,
+    },
+    total=False,
+)
+
+
+class DescribeDomainChangeProgressRequestRequestTypeDef(
+    _RequiredDescribeDomainChangeProgressRequestRequestTypeDef,
+    _OptionalDescribeDomainChangeProgressRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeDomainChangeProgressResponseTypeDef = TypedDict(
+    "DescribeDomainChangeProgressResponseTypeDef",
+    {
+        "ChangeProgressStatus": "ChangeProgressStatusDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
     "DescribeElasticsearchDomainConfigRequestRequestTypeDef",
     {
@@ -968,6 +1038,7 @@ ElasticsearchDomainConfigTypeDef = TypedDict(
         "DomainEndpointOptions": "DomainEndpointOptionsStatusTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsStatusTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsStatusTypeDef",
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
     },
     total=False,
 )
@@ -1004,6 +1075,7 @@ _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsOutputTypeDef",
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
     },
     total=False,
 )
@@ -1812,6 +1884,7 @@ UpgradeElasticsearchDomainResponseTypeDef = TypedDict(
         "DomainName": str,
         "TargetVersion": str,
         "PerformCheckOnly": bool,
+        "ChangeProgressDetails": "ChangeProgressDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
